Struct build_html::TableCell
source · pub struct TableCell(/* private fields */);Expand description
A single table cell
TableCell implements HtmlContainer, so it can be filled just like any other
Container.
Example
let cell = TableCell::new(TableCellType::Header)
.with_attributes([("id", "header-cell"), ("class", "headers")])
.with_paragraph("Here's a paragraph!")
.to_html_string();
assert_eq!(cell, r#"<th id="header-cell" class="headers"><p>Here's a paragraph!</p></th>"#);Implementations
sourceimpl TableCell
impl TableCell
sourcepub fn new(cell_type: TableCellType) -> Self
pub fn new(cell_type: TableCellType) -> Self
Create a new TableCell with the given type
sourcepub fn with_attributes<A, S>(self, attributes: A) -> Self
pub fn with_attributes<A, S>(self, attributes: A) -> Self
Set the attributes for this row.
Note that this operation overrides all previous invocations of with_attributes.
Example
let out = TableCell::default()
.with_attributes([("id", "first-cell")])
.with_paragraph("Hello, World!")
.to_html_string();
assert_eq!(out, r#"<td id="first-cell"><p>Hello, World!</p></td>"#)Trait Implementations
sourceimpl Html for TableCell
impl Html for TableCell
sourcefn to_html_string(&self) -> String
fn to_html_string(&self) -> String
Convert this element into an HTML string Read more
sourceimpl HtmlContainer for TableCell
impl HtmlContainer for TableCell
sourcefn add_html<H: Html>(&mut self, html: H)
fn add_html<H: Html>(&mut self, html: H)
Adds the specified HTML element to this container Read more
sourcefn with_html<H: Html>(self, html: H) -> Self
fn with_html<H: Html>(self, html: H) -> Self
Consumes the container, returning it with the specified HTML element added to it Read more
sourcefn add_container(&mut self, container: Container)
fn add_container(&mut self, container: Container)
Add the container to this HTML Container Read more
sourcefn with_container(self, container: Container) -> Self
fn with_container(self, container: Container) -> Self
Nest the specified container within this container Read more
sourcefn with_table(self, table: Table) -> Self
fn with_table(self, table: Table) -> Self
Nest the specified
Table within this container Read moresourcefn add_header(&mut self, level: u8, text: impl ToString)
fn add_header(&mut self, level: u8, text: impl ToString)
Adds a header tag with the designated level to this container Read more
sourcefn with_header(self, level: u8, text: impl ToString) -> Self
fn with_header(self, level: u8, text: impl ToString) -> Self
Adds a header tag with the designated level to this container Read more
sourcefn add_header_attr<A, S>(&mut self, level: u8, text: impl ToString, attr: A)
fn add_header_attr<A, S>(&mut self, level: u8, text: impl ToString, attr: A)
Adds a header tag with the designated level and attributes to this container. Read more
sourcefn with_header_attr<A, S>(self, level: u8, text: impl ToString, attr: A) -> Self
fn with_header_attr<A, S>(self, level: u8, text: impl ToString, attr: A) -> Self
Adds a header tag with the designated level and attributes to this container. Read more
sourcefn add_image(&mut self, src: impl ToString, alt: impl ToString)
fn add_image(&mut self, src: impl ToString, alt: impl ToString)
Adds an
<img> tag to this container Read moresourcefn with_image(self, src: impl ToString, alt: impl ToString) -> Self
fn with_image(self, src: impl ToString, alt: impl ToString) -> Self
Adds an
<img> tag to this container Read moresourcefn add_image_attr<A, S>(
&mut self,
src: impl ToString,
alt: impl ToString,
attr: A,
)
fn add_image_attr<A, S>( &mut self, src: impl ToString, alt: impl ToString, attr: A, )
Adds an
<img> tag with the specified attributes to this container Read moresourcefn with_image_attr<A, S>(
self,
src: impl ToString,
alt: impl ToString,
attr: A,
) -> Self
fn with_image_attr<A, S>( self, src: impl ToString, alt: impl ToString, attr: A, ) -> Self
Adds an
<img> tag with the specified attributes to this container Read moresourcefn add_link(&mut self, href: impl ToString, text: impl ToString)
fn add_link(&mut self, href: impl ToString, text: impl ToString)
Adds an
<a> tag to this container Read moresourcefn with_link(self, href: impl ToString, text: impl ToString) -> Self
fn with_link(self, href: impl ToString, text: impl ToString) -> Self
Adds an
<a> tag to this container Read moresourcefn add_link_attr<A, S>(
&mut self,
href: impl ToString,
text: impl ToString,
attr: A,
)
fn add_link_attr<A, S>( &mut self, href: impl ToString, text: impl ToString, attr: A, )
Adds an
<a> tag with the specified attributes to this container Read moresourcefn with_link_attr<A, S>(
self,
href: impl ToString,
text: impl ToString,
attr: A,
) -> Self
fn with_link_attr<A, S>( self, href: impl ToString, text: impl ToString, attr: A, ) -> Self
Adds an
<a> tag with the specified attributes to this container Read moresourcefn add_paragraph(&mut self, text: impl ToString)
fn add_paragraph(&mut self, text: impl ToString)
Adds a
<p> tag element to this Container Read moresourcefn with_paragraph(self, text: impl ToString) -> Self
fn with_paragraph(self, text: impl ToString) -> Self
Adds a
<p> tag element to this Container Read moresourcefn add_paragraph_attr<A, S>(&mut self, text: impl ToString, attr: A)
fn add_paragraph_attr<A, S>(&mut self, text: impl ToString, attr: A)
Adds a
<p> tag element with the specified attributes to this Container Read moresourcefn with_paragraph_attr<A, S>(self, text: impl ToString, attr: A) -> Self
fn with_paragraph_attr<A, S>(self, text: impl ToString, attr: A) -> Self
Adds a
<p> tag element with the specified attributes to this Container Read moresourcefn add_preformatted(&mut self, text: impl ToString)
fn add_preformatted(&mut self, text: impl ToString)
Adds a
<pre> tag element to this container Read moresourcefn with_preformatted(self, text: impl ToString) -> Self
fn with_preformatted(self, text: impl ToString) -> Self
Adds a
<pre> tag element to this container Read moresourcefn add_preformatted_attr<A, S>(&mut self, text: impl ToString, attr: A)
fn add_preformatted_attr<A, S>(&mut self, text: impl ToString, attr: A)
Adds a
<pre> tag element with the specified attributes to this container Read moresourcefn with_preformatted_attr<A, S>(self, text: impl ToString, attr: A) -> Self
fn with_preformatted_attr<A, S>(self, text: impl ToString, attr: A) -> Self
Adds a
<pre> tag element with the specified attributes to this container Read moreAuto Trait Implementations
impl Freeze for TableCell
impl RefUnwindSafe for TableCell
impl Send for TableCell
impl Sync for TableCell
impl Unpin for TableCell
impl UnwindSafe for TableCell